@@ -578,7 +578,7 @@ class NlpClient(AbstractClient):
 
         目前已提供：
 
-        - 通用领域分类体系，二级分类，包括15个分类类目，分别是汽车、科技、健康、体育、旅行、教育、职业、文化、军事、房产、娱乐、女性、奥运、财经以及其他，适用于通用的场景。
+        - 通用领域分类体系，二级分类，包括14个分类类目，分别是汽车、科技、健康、体育、旅行、教育、职业、文化、房产、娱乐、女性、奥运、财经以及其他，适用于通用的场景。
 
         - 新闻领域分类体系，五级分类，包括35个一级分类类目，228个二级分类，493个三级分类，204个四级分类，40个五级分类（详细请见附录->文本分类映射表），已应用于腾讯新闻的文章分类。
 
@@ -642,6 +642,8 @@ class NlpClient(AbstractClient):
 
         鉴于句子相似度是一个应用非常广泛的功能，腾讯云自然语言处理团队在Bert等领先的深度神经网络模型的基础上，专门针对文本相似任务进行了优化，并持续迭代更新。基于句子相似度，可以轻松实现诸如文本去重、相似推荐等功能。
 
+        接口将以句子数量为单位消耗资源包，而不是调用接口次数为单位。
+
         :param request: Request instance for TextSimilarity.
         :type request: :class:`tencentcloud.nlp.v20190408.models.TextSimilarityRequest`
         :rtype: :class:`tencentcloud.nlp.v20190408.models.TextSimilarityResponse`
