@@ -253,6 +253,7 @@ class CreateGroupRequest(AbstractModel):
 类型： 
 1: 通用图库，以用户输入图提取特征。
 2: 灰度图库，输入图和搜索图均转为灰度图提取特征。
+3: 针对电商（通用品类）和logo优化。
         :type GroupType: int
         """
         self.GroupId = None
@@ -1120,14 +1121,18 @@ class DetectProductBetaRequest(AbstractModel):
         :param ImageBase64: 图片经过base64编码的内容。最大不超过1M，分辨率在25万到100万之间。 
 与ImageUrl同时存在时优先使用ImageUrl字段。
         :type ImageBase64: str
+        :param NeedLemma: 是否需要百科信息 1：是，0: 否，默认是0
+        :type NeedLemma: int
         """
         self.ImageUrl = None
         self.ImageBase64 = None
+        self.NeedLemma = None
 
 
     def _deserialize(self, params):
         self.ImageUrl = params.get("ImageUrl")
         self.ImageBase64 = params.get("ImageBase64")
+        self.NeedLemma = params.get("NeedLemma")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -1461,6 +1466,42 @@ class ImageInfo(AbstractModel):
         
 
 
+class ImageRect(AbstractModel):
+    """图像主体区域坐标
+
+    """
+
+    def __init__(self):
+        r"""
+        :param X: 左上角横坐标。
+        :type X: int
+        :param Y: 左上角纵坐标。
+        :type Y: int
+        :param Width: 宽度。
+        :type Width: int
+        :param Height: 高度。
+        :type Height: int
+        """
+        self.X = None
+        self.Y = None
+        self.Width = None
+        self.Height = None
+
+
+    def _deserialize(self, params):
+        self.X = params.get("X")
+        self.Y = params.get("Y")
+        self.Width = params.get("Width")
+        self.Height = params.get("Height")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
 class Labels(AbstractModel):
     """名人识别的标签
 
@@ -1491,6 +1532,41 @@ class Labels(AbstractModel):
         
 
 
+class LemmaInfo(AbstractModel):
+    """百科词条信息
+
+    """
+
+    def __init__(self):
+        r"""
+        :param LemmaTitle: 词条
+注意：此字段可能返回 null，表示取不到有效值。
+        :type LemmaTitle: str
+        :param LemmaAbstract: 词条描述
+注意：此字段可能返回 null，表示取不到有效值。
+        :type LemmaAbstract: str
+        :param Tag: 标签
+注意：此字段可能返回 null，表示取不到有效值。
+        :type Tag: str
+        """
+        self.LemmaTitle = None
+        self.LemmaAbstract = None
+        self.Tag = None
+
+
+    def _deserialize(self, params):
+        self.LemmaTitle = params.get("LemmaTitle")
+        self.LemmaAbstract = params.get("LemmaAbstract")
+        self.Tag = params.get("Tag")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
 class Location(AbstractModel):
     """检测到的主体在图片中的矩形框位置（四个顶点坐标）
 
@@ -1603,6 +1679,9 @@ class ProductInfo(AbstractModel):
         :type Score: float
         :param Image: 搜索到的商品配图URL。
         :type Image: str
+        :param LemmaInfoList: 百科词条列表
+注意：此字段可能返回 null，表示取不到有效值。
+        :type LemmaInfoList: list of LemmaInfo
         """
         self.FindSKU = None
         self.Location = None
@@ -1612,6 +1691,7 @@ class ProductInfo(AbstractModel):
         self.ProductCategory = None
         self.Score = None
         self.Image = None
+        self.LemmaInfoList = None
 
 
     def _deserialize(self, params):
@@ -1625,6 +1705,12 @@ class ProductInfo(AbstractModel):
         self.ProductCategory = params.get("ProductCategory")
         self.Score = params.get("Score")
         self.Image = params.get("Image")
+        if params.get("LemmaInfoList") is not None:
+            self.LemmaInfoList = []
+            for item in params.get("LemmaInfoList"):
+                obj = LemmaInfo()
+                obj._deserialize(item)
+                self.LemmaInfoList.append(obj)
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -1771,6 +1857,8 @@ Url、Image必须提供一个，如果都提供，只使用 Url。
         :type Limit: int
         :param Filter: 针对入库时提交的Tags信息进行条件过滤。支持>、>=、 <、 <=、=，!=，多个条件之间支持AND和OR进行连接。
         :type Filter: str
+        :param ImageRect: 图像主体区域。
+        :type ImageRect: :class:`tencentcloud.tiia.v20190529.models.ImageRect`
         """
         self.GroupId = None
         self.ImageUrl = None
@@ -1779,6 +1867,7 @@ Url、Image必须提供一个，如果都提供，只使用 Url。
         self.Offset = None
         self.Limit = None
         self.Filter = None
+        self.ImageRect = None
 
 
     def _deserialize(self, params):
@@ -1789,6 +1878,9 @@ Url、Image必须提供一个，如果都提供，只使用 Url。
         self.Offset = params.get("Offset")
         self.Limit = params.get("Limit")
         self.Filter = params.get("Filter")
+        if params.get("ImageRect") is not None:
+            self.ImageRect = ImageRect()
+            self.ImageRect._deserialize(params.get("ImageRect"))
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
